// Wait for the deviceready event before using any of Cordova's device APIs.
// See https://cordova.apache.org/docs/en/latest/cordova/events/events.html#deviceready
document.addEventListener('deviceready', onDeviceReady, false);

function onDeviceReady() {
    // Cordova is now initialized. Have fun!

    console.log('Running cordova-' + cordova.platformId + '@' + cordova.version);
    getCoordinates();
}

/* MQTT & WEBSQL */
var mqtt = { hostname: "test.mosquitto.org", port: 8081 };
var topic_top = "GeoTrack";
var publish_cnt = 0, gObj;
var markers = [];
var mqttConnected = false;

/* Google Maps */
var theMap;
var latitude = 25.05; 
var longitude = 121.374818; 
var YOUR_KEY = "";

function getCoordinates() {
    navigator.geolocation.getCurrentPosition(onSuccess, onError);
    setTimeout(getCoordinates, 60000); // milliseconds
}

var onSuccess = function(pos) {
    // Update global variables
    latitude = pos.coords.latitude;
    longitude = pos.coords.longitude;
    console.log('Latitude: '+ pos.coords.latitude + ' ' +
                'Longitude: '+ pos.coords.longitude);        
};

function onError(error) {
    alert('code: '    + error.code    + '\n' +
          'message: ' + error.message + '\n');
}

/* Google Maps */
function gMap() {
    $.getScript("https://maps.googleapis.com/maps/api/js?key="+YOUR_KEY+"&callback=gMapCallback");     
}

function gMapCallback() {
    center = new google.maps.LatLng(latitude, longitude);
    config = {center: center, zoom: 10,};
    theMap = new google.maps.Map(document.getElementById("googleMap"), config);
    console.log( "Map Created" );
    refreshAll()
}

/* MQTT */
function onConnectionLost(responseObject) {
    mqttConnected = false;
    console.log("onConnectionLost: "+responseObject.errorCode+" "+responseObject.errorMessage);
}

function onMessageArrived(message) {
    console.log("onMessageArrived: "+message.payloadString);
    console.log("your name: " + dbLocal.getItem("your-name"));
    gObj = JSON.parse(message.payloadString);
    sql="SELECT * FROM trackgroup WHERE userid=?";
    dbInst.execute(sql, [ gObj.userid ], onSelectSuccess);    
}

/* WEBSQL */
function InitDB() { 
    sql="CREATE TABLE IF NOT EXISTS trackgroup (userid, lat REAL, lon REAL, self, timestamp INTEGER, UNIQUE(userid))";
    dbInst.execute(sql);
    removeExpired();
}

function onSelectSuccess(rows, n, rowsAffected) {
    if(n == 0) {
        // insert
        sql="INSERT INTO trackgroup (userid, lat, lon, self, timestamp) VALUES (?, ?, ?, ?, ?)";
        if(gObj.userid == dbLocal.getItem("your-name")) self_flag = 1; else self_flag = 0;
        dbInst.execute(sql, [ gObj.userid, gObj.lat, gObj.lon, self_flag, gObj.timestamp ], refreshAll);
    } else {
        // update
        sql="UPDATE trackgroup SET lat=?, lon=?, timestamp=? WHERE userid=?";
        dbInst.execute(sql, [ gObj.lat, gObj.lon, gObj.timestamp, gObj.userid ], refreshAll); 
    }
}

function refreshAll() {
    sql="SELECT * FROM trackgroup";
    dbInst.execute(sql, [], refreshData);
}

function refreshData(rows, n, rowsAffected) {
    html = "";
    for(var i=0; i<n; i++) {
        console.log(rows[i].userid + " / " + rows[i].lat + " / " + rows[i].lon + " / " + rows[i].self + " / " + rows[i].timestamp );
        html += "<tr><td width='50%'>"+rows[i].userid+"</td>";
		html += "<td width='20%'>"+convertTimeStamp(rows[i].timestamp)+"</td></tr>";
    }
    
    // List group people
    $("#listview").html(html);  
    
    // Remove all markers on Google Maps
    for (var i = 0; i < markers.length; i++ ) {
        markers[i].setMap(null);
    }
    markers.length = 0;
    
    // Add all markers on Google Maps
    for(var i=0; i<n; i++) {
        center = new google.maps.LatLng(rows[i].lat, rows[i].lon);
        if(rows[i].self == 1) 
            url_png = "img/red-dot.png";
        else
            url_png = "img/purple-dot.png"

        marker = new google.maps.Marker({ 
            position: center, icon: url_png, 
            label: { text: rows[i].userid, color: "white", fontSize:"20px" } 
            });
        marker.setMap(theMap);
        if(rows[i].self == 1) theMap.setCenter(marker.getPosition());        
        markers.push(marker); 
    }
}

function removeExpired() {
    expired = getTimeStamp() - 3*60;
    sql="DELETE FROM trackgroup WHERE timestamp<? or (self=1 and userid<>?)";
    dbInst.execute(sql, [ expired, dbLocal.getItem("your-name") ]); 
    setTimeout(removeExpired, 30*60000); // milliseconds        
}

function getTimeStamp() {
    var today = new Date();
    return Math.floor(today.getTime() / (1000*60)); // minutes
}

function convertTimeStamp(stamp) {
	// stamp : minutes
	var a = new Date(stamp * 60 * 1000); // milliseconds
	return a.getHours() + ":" + a.getMinutes();
}

   
